==> tecfy_core_package-0.1.3.tar.gz: lib/views/components/home/bottom_navigation_bar.dart <==
part of tecfy_core_client_package;


class MainBottomNavigationBar extends StatelessWidget {
  final int selected;
  final bool isMainPage;
  MainBottomNavigationBar(this.selected,this.isMainPage);

  final double width =59.0;
  final double selectedWidth =70.0;
 
  @override
  Widget build(BuildContext context) {
    return  
    Container( 
      height: 90.0,      
      child:
      Stack(
        children: <Widget>[
          Container(            
            margin: EdgeInsets.only(top: 15.0),
            decoration: new BoxDecoration(
              color: Colors.white,
              border: Border(
                top:BorderSide( 
                  color: ThemeService.black26Gray,
                  width: .1)
              )
            )
              
          ),
          Hero(tag:'hero-bottom', child:
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: <Widget>[
              getIcon(context,Icons.satellite,'Feed',2),
              getIcon(context,Icons.home,'My Wishooos',0),
              getIcon(context,Icons.people,'Friends',3),
              // !AccountService.isAnonymous?
              // StreamBuilder<int>(
              //   stream: UserNotificationService.unreadCountStream(),
              //   builder: (c,snap)=> getIcon(context,Icons.notifications,'Notifications',1,snap?.data?.toString()),
              // ):
              getIcon(context,Icons.notifications,'Notifications',1)
              //getIcon(context,Icons.person,'Profile',4)
            ],
          ))
        ],
      
       ));
  }
  getIcon(context,IconData icon,String name, int index,[String padge]){
    if(padge == '0') padge = null;
    //return Image.asset('assets/images/selected_bg.png', width: 60, height: 60.0,);
    return MaterialButton(
      highlightColor: Colors.transparent,
      //color: Colors.transparent,
      disabledColor: Colors.transparent,
      splashColor: Colors.transparent,
      minWidth: 10.0,
      //color: Colors.transparent,
      onPressed: ()=>navigateToPage(index,context),
      child:selected == index ?  
          //Container() //Hero(tag: 'hero-bottom-selected',child: Image.asset(image,width: width))
          
          //Image.asset('assets/images/selected_bg.png', width: 60, height: 60.0,)
          Hero(tag: 'hero-bottom-selected',child: Stack(
            children: <Widget>[
              Image.asset('assets/images/selected_bg.png', width: selectedWidth),
              Container(width: selectedWidth, child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                SizedBox(height: 3.0),
                Icon(icon,color:ThemeService.mainColor, size: 30.0),//   Image.asset(notSelectedImage,width: 20.0,height: 20.0),
                SizedBox(height: 3.0),
                Text(name, style: TextStyle(fontSize: 10.0, color: ThemeService.mainColor), maxLines: 1, softWrap: true, overflow: TextOverflow.fade, textAlign: TextAlign.center),
                SizedBox(height: 10.0),
              ],
              )),
              padge == null ? Container() : Padding(padding: EdgeInsets.fromLTRB(40,20,0,0), child:  CircleAvatar(backgroundColor: ThemeService.mainInvertColor,foregroundColor: ThemeService.mainTextColor,child: Text(padge,style: TextStyle(fontSize: 8.0),),radius: 8.0,))
            ],
          ))
          : 
          Stack(
            children: <Widget>[
              
          Container(width: width, child:  Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              SizedBox(height: 3.0),
              Icon(icon,color: ThemeService.mainInvertColor),//   Image.asset(notSelectedImage,width: 20.0,height: 20.0),
              SizedBox(height: 3.0),
              Text(name, style: TextStyle(fontSize: 9.0, color: ThemeService.mainInvertColor), maxLines: 1, softWrap: true, overflow: TextOverflow.fade, textAlign: TextAlign.center),
              SizedBox(height: 10.0),
            ],
            )),
            padge == null ? Container() :Padding(padding: EdgeInsets.fromLTRB(32,18,0,0), child:  CircleAvatar(backgroundColor: ThemeService.mainColor,foregroundColor: ThemeService.mainTextColor, child: Text(padge,style: TextStyle(fontSize: 8.0),),radius: 8.0,))
            ],
          )
    );
       
  }

  navigateToPage(index,context){
   //if(selected == index && isMainPage)return;
    switch(index){
      case 0:
        // return AppNavigator.navigateTo(context, ()=>MyWishooosListPage(), replaceAll: true, animationType: AnimationTypes.opacity);
      case 1:
        return AppNavigator.navigateTo(context, ()=>NotificationsListPage(), replaceAll: true, animationType: AnimationTypes.opacity);
      case 2:
        return AppNavigator.navigateTo(context, ()=>DashboardPage(), replaceAll: true, animationType: AnimationTypes.opacity);
      case 3:
        // return AppNavigator.navigateTo(context, ()=>FriendsPage(), replaceAll: true, animationType: AnimationTypes.opacity);
      default:
    }
  }
}

==> tecfy_core_package-0.1.8.tar.gz: lib/views/components/home/bottom_navigation_bar.dart <==
part of tecfy_core_client_package;


class MainBottomNavigationBar extends StatelessWidget {
  final int selected;
  final bool isMainPage;
  MainBottomNavigationBar(this.selected,this.isMainPage);

  final double width =59.0;
  final double selectedWidth =70.0;
 
  @override
  Widget build(BuildContext context) {
    return  
    Container( 
      height: 90.0,      
      child:
      Stack(
        children: <Widget>[
          Container(            
            margin: EdgeInsets.only(top: 15.0),
            decoration: new BoxDecoration(
              color: Colors.white,
              border: Border(
                top:BorderSide( 
                  color: ThemeService.backgroundSecondColor,
                  width: .1)
              )
            )
              
          ),
          Hero(tag:'hero-bottom', child:
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: <Widget>[
              getIcon(context,Icons.satellite,'Feed',2),
              getIcon(context,Icons.home,'My Wishooos',0),
              getIcon(context,Icons.people,'Friends',3),
              // !AccountService.isAnonymous?
              // StreamBuilder<int>(
              //   stream: UserNotificationService.unreadCountStream(),
              //   builder: (c,snap)=> getIcon(context,Icons.notifications,'Notifications',1,snap?.data?.toString()),
              // ):
              getIcon(context,Icons.notifications,'Notifications',1)
              //getIcon(context,Icons.person,'Profile',4)
            ],
          ))
        ],
      
       ));
  }
  getIcon(context,IconData icon,String name, int index,[String padge]){
    if(padge == '0') padge = null;
    //return Image.asset('assets/images/selected_bg.png', width: 60, height: 60.0,);
    return MaterialButton(
      highlightColor: Colors.transparent,
      //color: Colors.transparent,
      disabledColor: Colors.transparent,
      splashColor: Colors.transparent,
      minWidth: 10.0,
      //color: Colors.transparent,
      onPressed: ()=>navigateToPage(index,context),
      child:selected == index ?  
          //Container() //Hero(tag: 'hero-bottom-selected',child: Image.asset(image,width: width))
          
          //Image.asset('assets/images/selected_bg.png', width: 60, height: 60.0,)
          Hero(tag: 'hero-bottom-selected',child: Stack(
            children: <Widget>[
              Image.asset('assets/images/selected_bg.png', width: selectedWidth),
              Container(width: selectedWidth, child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                SizedBox(height: 3.0),
                Icon(icon,color:ThemeService.mainColor, size: 30.0),//   Image.asset(notSelectedImage,width: 20.0,height: 20.0),
                SizedBox(height: 3.0),
                Text(name, style: TextStyle(fontSize: 10.0, color: ThemeService.mainColor), maxLines: 1, softWrap: true, overflow: TextOverflow.fade, textAlign: TextAlign.center),
                SizedBox(height: 10.0),
              ],
              )),
              padge == null ? Container() : Padding(padding: EdgeInsets.fromLTRB(40,20,0,0), child:  CircleAvatar(backgroundColor: ThemeService.mainInvertColor,foregroundColor: ThemeService.mainTextColor,child: Text(padge,style: TextStyle(fontSize: 8.0),),radius: 8.0,))
            ],
          ))
          : 
          Stack(
            children: <Widget>[
              
          Container(width: width, child:  Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              SizedBox(height: 3.0),
              Icon(icon,color: ThemeService.mainInvertColor),//   Image.asset(notSelectedImage,width: 20.0,height: 20.0),
              SizedBox(height: 3.0),
              Text(name, style: TextStyle(fontSize: 9.0, color: ThemeService.mainInvertColor), maxLines: 1, softWrap: true, overflow: TextOverflow.fade, textAlign: TextAlign.center),
              SizedBox(height: 10.0),
            ],
            )),
            padge == null ? Container() :Padding(padding: EdgeInsets.fromLTRB(32,18,0,0), child:  CircleAvatar(backgroundColor: ThemeService.mainColor,foregroundColor: ThemeService.mainTextColor, child: Text(padge,style: TextStyle(fontSize: 8.0),),radius: 8.0,))
            ],
          )
    );
       
  }

  navigateToPage(index,context){
   //if(selected == index && isMainPage)return;
    switch(index){
      case 0:
        // return AppNavigator.navigateTo(context, ()=>MyWishooosListPage(), replaceAll: true, animationType: AnimationTypes.opacity);
      case 1:
        return AppNavigator.navigateTo(context, ()=>NotificationsListPage(), replaceAll: true, animationType: AnimationTypes.opacity);
      case 2:
        return AppNavigator.navigateTo(context, ()=>DashboardPage(), replaceAll: true, animationType: AnimationTypes.opacity);
      case 3:
        // return AppNavigator.navigateTo(context, ()=>FriendsPage(), replaceAll: true, animationType: AnimationTypes.opacity);
      default:
    }
  }
}
